==> android_foreground_alive-0.0.2.tar.gz: android/src/main/java/com/dcy/android_foreground_alive/DcyForegroundService.java <==
package com.dcy.android_foreground_alive;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.drawable.Icon;
import android.os.Build;
import android.os.IBinder;

public class DcyForegroundService extends Service {
    public DcyForegroundService() {
    }

    @Override
    public IBinder onBind(Intent intent) {
        // TODO: Return the communication channel to the service.
        return null;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        appName = AppUtils.getAppName(getBaseContext());
        notificationId = appName+"serviceid";
        notificationName = appName+"servicename";
        Bitmap bitmap = AppUtils.getBitmap(getBaseContext());
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.M) {
            icon = Icon.createWithBitmap(bitmap);
        }else{
            icon = Icon.createWithResource(getBaseContext(),R.mipmap.ic_launcher);
        }
        showNotification();
    }

    private String notificationId = "serviceid";
    private String notificationName = "servicename";
    String appName = "";
    Icon icon;

    private void showNotification(){

        NotificationManager notificationManager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);
        //创建NotificationChannel
        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.O){
            NotificationChannel channel = new NotificationChannel(notificationId, notificationName, NotificationManager.IMPORTANCE_HIGH);
            notificationManager.createNotificationChannel(channel);
            startForeground(1,getNotification());
        } else {
            // 创建通知(标题、内容、图标)
            Notification notification = null;
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN) {
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                    notification = new Notification.Builder(this)
                            .setContentTitle(appName)
                            .setContentText("正在运行")
                            .setSmallIcon(icon)
                            .build();
                }else{
                    notification = new Notification.Builder(this)
                            .setContentTitle(appName)
                            .setContentText("正在运行")
                            .setSmallIcon(R.mipmap.ic_launcher)
                            .build();
                }
            }
            // 创建通知管理器
            NotificationManager manager = (NotificationManager) getApplicationContext()
                    .getSystemService(Context.NOTIFICATION_SERVICE);
// 发送通知
            manager.notify(1, notification);
        }
    }
    private Notification getNotification() {
        Notification.Builder builder = null;
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                builder = new Notification.Builder(this)
                        .setContentTitle(appName)
                        .setContentText("正在运行")
                        .setSmallIcon(icon);
            }else{
                builder = new Notification.Builder(this)
                        .setContentTitle(appName)
                        .setContentText("正在运行")
                        .setSmallIcon(R.mipmap.ic_launcher);
            }
        }
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            builder.setChannelId(notificationId);
        }
        Notification notification = null;
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN) {
            notification = builder.build();
        }
        return notification;
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        showNotification();
    }
}

==> android_foreground_alive-0.0.5.tar.gz: android/src/main/java/com/dcy/android_foreground_alive/DcyForegroundService.java <==
package com.dcy.android_foreground_alive;

import android.annotation.TargetApi;
import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.drawable.Icon;
import android.os.Build;
import android.os.IBinder;

public class DcyForegroundService extends Service {
    public DcyForegroundService() {
    }

    @Override
    public IBinder onBind(Intent intent) {
        // TODO: Return the communication channel to the service.
        return null;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        appName = AppUtils.getAppName(getBaseContext());
        notificationId = appName+"serviceid";
        notificationName = appName+"servicename";
        Bitmap bitmap = AppUtils.getBitmap(getBaseContext());
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.M) {
            icon = Icon.createWithBitmap(bitmap);
        }else{
            icon = Icon.createWithResource(getBaseContext(),R.mipmap.ic_launcher);
        }
        showNotification();
    }

    private String notificationId = "serviceid";
    private String notificationName = "servicename";
    String appName = "";
    Icon icon;

    private void showNotification(){

        NotificationManager notificationManager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);
        //创建NotificationChannel
        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.O){
            NotificationChannel channel = new NotificationChannel(notificationId, notificationName, NotificationManager.IMPORTANCE_HIGH);
            notificationManager.createNotificationChannel(channel);
            startForeground(1,getNotification());
        } else {
            // 创建通知(标题、内容、图标)
            Notification notification = null;
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN) {
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                    notification = new Notification.Builder(this)
                            .setContentTitle(appName)
                            .setContentText("正在运行")
                            .setSmallIcon(icon)
                            .build();
                }else{
                    notification = new Notification.Builder(this)
                            .setContentTitle(appName)
                            .setContentText("正在运行")
                            .setSmallIcon(R.mipmap.ic_launcher)
                            .build();
                }
            }
            // 创建通知管理器
            NotificationManager manager = (NotificationManager) getApplicationContext()
                    .getSystemService(Context.NOTIFICATION_SERVICE);
// 发送通知
            manager.notify(1, notification);
        }
    }

    @TargetApi(Build.VERSION_CODES.O)
    private Notification getNotification() {
        Notification.Builder builder = null;

        builder = new Notification.Builder(this,"")
                .setContentTitle(appName)
                .setContentText("正在运行")
                .setSmallIcon(icon);

        Notification notification = null;
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN) {
            notification = builder.build();
        }
        return notification;
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        showNotification();
    }
}
